EXPORTS
	??0CCoeFep@@IAE@AAVCCoeEnv@@@Z @ 1 NONAME ; protected: __thiscall CCoeFep::CCoeFep(class CCoeEnv &)
	??1CCoeFep@@UAE@XZ @ 2 NONAME ; public: virtual __thiscall CCoeFep::~CCoeFep(void)
	?OfferPointerEvent@CCoeFep@@QAE?AW4TEventResponse@1@AAHAAVMKeyEventQueue@1@ABUTPointerEvent@@PBVCCoeControl@@@Z @ 3 NONAME ABSENT; public: enum CCoeFep::TEventResponse  __thiscall CCoeFep::OfferPointerEvent(int &,class CCoeFep::MKeyEventQueue &,struct TPointerEvent const &,class CCoeControl const *)
	??1CFepFastFileAccessor@@UAE@XZ @ 4 NONAME ABSENT ; public: virtual __thiscall CFepFastFileAccessor::~CFepFastFileAccessor(void)
	?AddFileL@CFepFastFileAccessor@@QAEXABVTDesC16@@@Z @ 5 NONAME ABSENT ; public: void __thiscall CFepFastFileAccessor::AddFileL(class TDesC16 const &)
	?OfferPointerBufferReadyEvent@CCoeFep@@QAE?AW4TEventResponse@1@AAHAAVMKeyEventQueue@1@PBVCCoeControl@@@Z @ 6 NONAME ABSENT; public: enum CCoeFep::TEventResponse  __thiscall CCoeFep::OfferPointerBufferReadyEvent(int &,class CCoeFep::MKeyEventQueue &,class CCoeControl const *)
	?BaseConstructL@CCoeFep@@IAEXABVCCoeFepParameters@@@Z @ 7 NONAME ; protected: void __thiscall CCoeFep::BaseConstructL(class CCoeFepParameters const &)
	?CCoeFep_Reserved_1@CCoeFep@@EAEXXZ @ 8 NONAME ; private: virtual void __thiscall CCoeFep::CCoeFep_Reserved_1(void)
	?CCoeFep_Reserved_2@CCoeFep@@EAEXXZ @ 9 NONAME ; private: virtual void __thiscall CCoeFep::CCoeFep_Reserved_2(void)
	?MKeyEventQueue_Reserved_1@MKeyEventQueue@CCoeFep@@EAEXXZ @ 10 NONAME ABSENT; private: virtual void __thiscall CCoeFep::MKeyEventQueue::MKeyEventQueue_Reserved_1(void)
	?MKeyEventQueue_Reserved_2@MKeyEventQueue@CCoeFep@@EAEXXZ @ 11 NONAME ABSENT; private: virtual void __thiscall CCoeFep::MKeyEventQueue::MKeyEventQueue_Reserved_2(void)
	?OfferEventToActiveScheduler@CCoeFep@@SA?AW4TEventResponse@1@PAV1@AAHAAVMKeyEventQueue@1@H@Z @ 12 NONAME ABSENT; public: static enum CCoeFep::TEventResponse  __cdecl CCoeFep::OfferEventToActiveScheduler(class CCoeFep *,int &,class CCoeFep::MKeyEventQueue &,int)
	?OfferKeyEvent@CCoeFep@@QAE?AW4TEventResponse@1@AAHAAVMKeyEventQueue@1@ABUTKeyEvent@@W4TEventCode@@@Z @ 13 NONAME ABSENT; public: enum CCoeFep::TEventResponse  __thiscall CCoeFep::OfferKeyEvent(int &,class CCoeFep::MKeyEventQueue &,struct TKeyEvent const &,enum TEventCode)
	?FileHasChangedL@CFepFastFileAccessor@@QAEXABVTDesC16@@@Z @ 14 NONAME ABSENT ; public: void __thiscall CFepFastFileAccessor::FileHasChangedL(class TDesC16 const &)
	?RemoveFile@CFepFastFileAccessor@@QAEXABVTDesC16@@@Z @ 15 NONAME ABSENT ; public: void __thiscall CFepFastFileAccessor::RemoveFile(class TDesC16 const &)
	?GetData@CFepFastFileAccessor@@ABEXABVTDesC16@@AAPBEAAHPAH@Z @ 16 NONAME ABSENT ; private: void __thiscall CFepFastFileAccessor::GetData(class TDesC16 const &,unsigned char const * &,int &,int *)const 
	?IsTurnedOffByL@CCoeFep@@QBEHABUTKeyEvent@@@Z @ 17 NONAME ; public: int __thiscall CCoeFep::IsTurnedOffByL(struct TKeyEvent const &)const 
	?IsTurnedOnByL@CCoeFep@@QBEHABUTKeyEvent@@@Z @ 18 NONAME ; public: int __thiscall CCoeFep::IsTurnedOnByL(struct TKeyEvent const &)const 
	?MCoeCaptionRetrieverForFep_Reserved_1@MCoeCaptionRetrieverForFep@@EAEXXZ @ 19 NONAME ; private: virtual void __thiscall MCoeCaptionRetrieverForFep::MCoeCaptionRetrieverForFep_Reserved_1(void)
	?MCoeCaptionRetrieverForFep_Reserved_2@MCoeCaptionRetrieverForFep@@EAEXXZ @ 20 NONAME ; private: virtual void __thiscall MCoeCaptionRetrieverForFep::MCoeCaptionRetrieverForFep_Reserved_2(void)
	?MakeDeferredFunctionCall@CCoeFep@@IAEXAAVMDeferredFunctionCall@1@@Z @ 21 NONAME ; protected: void __thiscall CCoeFep::MakeDeferredFunctionCall(class CCoeFep::MDeferredFunctionCall &)
	?IsSimulatingKeyEvent@CCoeFep@@QBEHXZ @ 22 NONAME ; public: int __thiscall CCoeFep::IsSimulatingKeyEvent(void)const 
	?Extension1@MCoeFepAwareTextEditor@@EAEPAVMCoeFepAwareTextEditor_Extension1@@AAH@Z @ 23 NONAME ; private: virtual class MCoeFepAwareTextEditor_Extension1 * __thiscall MCoeFepAwareTextEditor::Extension1(int &)
	?MCoeFepAwareTextEditor_Reserved_2@MCoeFepAwareTextEditor@@EAEXXZ @ 24 NONAME ; private: virtual void __thiscall MCoeFepAwareTextEditor::MCoeFepAwareTextEditor_Reserved_2(void)
	?MFepInlineTextFormatRetriever_Reserved_1@MFepInlineTextFormatRetriever@@EAEXXZ @ 25 NONAME ; private: virtual void __thiscall MFepInlineTextFormatRetriever::MFepInlineTextFormatRetriever_Reserved_1(void)
	?MFepInlineTextFormatRetriever_Reserved_2@MFepInlineTextFormatRetriever@@EAEXXZ @ 26 NONAME ; private: virtual void __thiscall MFepInlineTextFormatRetriever::MFepInlineTextFormatRetriever_Reserved_2(void)
	?NewL@CCoeFepParameters@@SAPAV1@ABVTFepOnOrOffKeyData@@0H@Z @ 27 NONAME ABSENT ; public: static class CCoeFepParameters * __cdecl CCoeFepParameters::NewL(class TFepOnOrOffKeyData const &,class TFepOnOrOffKeyData const &,int)
	?NewL@CFepFastFileAccessor@@CAPAV1@AAVCCoeEnv@@PAVMFileObserver@1@@Z @ 28 NONAME ABSENT ; private: static class CFepFastFileAccessor * __cdecl CFepFastFileAccessor::NewL(class CCoeEnv &,class CFepFastFileAccessor::MFileObserver *)
	?NewLC@CCoeFepParameters@@SAPAV1@ABVTFepOnOrOffKeyData@@0H@Z @ 29 NONAME ABSENT ; public: static class CCoeFepParameters * __cdecl CCoeFepParameters::NewLC()
	?NewLC@CFepFastFileAccessor@@CAPAV1@AAVCCoeEnv@@PAVMFileObserver@1@@Z @ 30 NONAME ABSENT ; private: static class CFepFastFileAccessor * __cdecl CFepFastFileAccessor::NewLC(class CCoeEnv &,class CFepFastFileAccessor::MFileObserver *)
	?ReadAllAttributesL@CCoeFep@@IAEXXZ @ 31 NONAME ; protected: void __thiscall CCoeFep::ReadAllAttributesL(void)
	?SimulateKeyEventsL@CCoeFep@@IAEXABV?$TArray@I@@@Z @ 32 NONAME ; protected: void __thiscall CCoeFep::SimulateKeyEventsL(class TArray<unsigned int> const &)
	?WriteAttributeDataAndBroadcastL@CCoeFep@@IAEXVTUid@@@Z @ 33 NONAME ; protected: void __thiscall CCoeFep::WriteAttributeDataAndBroadcastL(class TUid)
	?NewL@CFepGenericGlobalSettings@@SAPAV1@AAVCCoeEnv@@ABVTFepOnOrOffKeyData@@1H@Z @ 34 NONAME ; public: static class CFepGenericGlobalSettings * __cdecl CFepGenericGlobalSettings::NewL(class CCoeEnv &,class TFepOnOrOffKeyData const &,class TFepOnOrOffKeyData const &,int)
	?NewLC@CFepGenericGlobalSettings@@SAPAV1@AAVCCoeEnv@@ABVTFepOnOrOffKeyData@@1H@Z @ 35 NONAME ; public: static class CFepGenericGlobalSettings * __cdecl CFepGenericGlobalSettings::NewLC(class CCoeEnv &,class TFepOnOrOffKeyData const &,class TFepOnOrOffKeyData const &,int)
	?OffKeyData@CFepGenericGlobalSettings@@QBE?AVTFepOnOrOffKeyData@@XZ @ 36 NONAME ; public: class TFepOnOrOffKeyData  __thiscall CFepGenericGlobalSettings::OffKeyData(void)const 
	?OnKeyData@CFepGenericGlobalSettings@@QBE?AVTFepOnOrOffKeyData@@XZ @ 37 NONAME ; public: class TFepOnOrOffKeyData  __thiscall CFepGenericGlobalSettings::OnKeyData(void)const 
	?RefreshL@CFepGenericGlobalSettings@@QAEXXZ @ 38 NONAME ; public: void __thiscall CFepGenericGlobalSettings::RefreshL(void)
	?SetOffKeyData@CFepGenericGlobalSettings@@QAEXABVTFepOnOrOffKeyData@@@Z @ 39 NONAME ; public: void __thiscall CFepGenericGlobalSettings::SetOffKeyData(class TFepOnOrOffKeyData const &)
	?SetOnKeyData@CFepGenericGlobalSettings@@QAEXABVTFepOnOrOffKeyData@@@Z @ 40 NONAME ; public: void __thiscall CFepGenericGlobalSettings::SetOnKeyData(class TFepOnOrOffKeyData const &)
	?StoreChangesAndBroadcastL@CFepGenericGlobalSettings@@QAEXXZ @ 41 NONAME ; public: void __thiscall CFepGenericGlobalSettings::StoreChangesAndBroadcastL(void)
	?FepObserverHandleStartOfTransactionL@@YAXAAVMCoeFepObserver@@@Z @ 42 NONAME ; void __cdecl FepObserverHandleStartOfTransactionL(class MCoeFepObserver &)
	?MCoeFepObserver_Reserved_1@MCoeFepObserver@@EAEXXZ @ 43 NONAME ; private: virtual void __thiscall MCoeFepObserver::MCoeFepObserver_Reserved_1(void)
	?MCoeFepObserver_Reserved_2@MCoeFepObserver@@EAEXXZ @ 44 NONAME ; private: virtual void __thiscall MCoeFepObserver::MCoeFepObserver_Reserved_2(void)
	??1CFepGlobalDynamicFrequencyTable@@UAE@XZ @ 45 NONAME ABSENT ; public: virtual __thiscall CFepGlobalDynamicFrequencyTable::~CFepGlobalDynamicFrequencyTable(void)
	?IncrementFrequencyOfCharacter@CFepGlobalDynamicFrequencyTable@@QAEXI@Z @ 46 NONAME ABSENT ; public: void __thiscall CFepGlobalDynamicFrequencyTable::IncrementFrequencyOfCharacter(unsigned int)
	?MCharacterArray_Reserved_1@MCharacterArray@CFepGlobalDynamicFrequencyTable@@EAEXXZ @ 47 NONAME ABSENT ; private: virtual void __thiscall CFepGlobalDynamicFrequencyTable::MCharacterArray::MCharacterArray_Reserved_1(void)
	?MCharacterArray_Reserved_2@MCharacterArray@CFepGlobalDynamicFrequencyTable@@EAEXXZ @ 48 NONAME ABSENT ; private: virtual void __thiscall CFepGlobalDynamicFrequencyTable::MCharacterArray::MCharacterArray_Reserved_2(void)
	?NewL@CFepGlobalDynamicFrequencyTable@@SAPAV1@H@Z @ 49 NONAME ABSENT ; public: static class CFepGlobalDynamicFrequencyTable * __cdecl CFepGlobalDynamicFrequencyTable::NewL(int)
	?NewLC@CFepGlobalDynamicFrequencyTable@@SAPAV1@H@Z @ 50 NONAME ABSENT ; public: static class CFepGlobalDynamicFrequencyTable * __cdecl CFepGlobalDynamicFrequencyTable::NewLC(int)
	?SortL@CFepGlobalDynamicFrequencyTable@@QAEXAAVMCharacterArray@1@P6AHII@ZW4TSortType@1@@Z @ 51 NONAME ABSENT ; public: void __thiscall CFepGlobalDynamicFrequencyTable::SortL(class CFepGlobalDynamicFrequencyTable::MCharacterArray &,int (__cdecl*)(unsigned int,unsigned int),enum CFepGlobalDynamicFrequencyTable::TSortType)
	?Reset@CFepGlobalDynamicFrequencyTable@@QAEXXZ @ 52 NONAME ABSENT ; public: void __thiscall CFepGlobalDynamicFrequencyTable::Reset(void)
	?IsOn@CCoeFep@@IBEHXZ @ 53 NONAME ; protected: int __thiscall CCoeFep::IsOn(void)const 
	?IsOn@CFepGenericGlobalSettings@@QBEHXZ @ 54 NONAME ; public: int __thiscall CFepGenericGlobalSettings::IsOn(void)const 
	?SetIsOn@CFepGenericGlobalSettings@@QAEXH@Z @ 55 NONAME ; public: void __thiscall CFepGenericGlobalSettings::SetIsOn(int)
	?MDeferredFunctionCall_Reserved_1@MDeferredFunctionCall@CCoeFep@@EAEXXZ @ 56 NONAME ; private: virtual void __thiscall CCoeFep::MDeferredFunctionCall::MDeferredFunctionCall_Reserved_1(void)
	?MDeferredFunctionCall_Reserved_2@MDeferredFunctionCall@CCoeFep@@EAEXXZ @ 57 NONAME ; private: virtual void __thiscall CCoeFep::MDeferredFunctionCall::MDeferredFunctionCall_Reserved_2(void)
	?HandleMessageL@CCoeFep@@EAE?AW4TMessageResponse@MCoeMessageObserver@@KVTUid@@ABVTDesC8@@@Z @ 58 NONAME ; private: virtual enum MCoeMessageObserver::TMessageResponse  __thiscall CCoeFep::HandleMessageL(unsigned long,class TUid,class TDesC8 const &)
	?ReadAllAttributesL@MFepAttributeStorer@@QAEXAAVCCoeEnv@@@Z @ 59 NONAME ; public: void __thiscall MFepAttributeStorer::ReadAllAttributesL(class CCoeEnv &)
	?WriteAttributeDataAndBroadcastL@MFepAttributeStorer@@QAEXAAVCCoeEnv@@ABV?$TArray@VTUid@@@@@Z @ 60 NONAME ; public: void __thiscall MFepAttributeStorer::WriteAttributeDataAndBroadcastL(class CCoeEnv &,class TArray<class TUid> const &)
	?WriteAttributeDataAndBroadcastL@MFepAttributeStorer@@QAEXAAVCCoeEnv@@VTUid@@@Z @ 61 NONAME ; public: void __thiscall MFepAttributeStorer::WriteAttributeDataAndBroadcastL(class CCoeEnv &,class TUid)
	?MFepAttributeStorer_Reserved_1@MFepAttributeStorer@@EAEXXZ @ 62 NONAME ; private: virtual void __thiscall MFepAttributeStorer::MFepAttributeStorer_Reserved_1(void)
	?MFepAttributeStorer_Reserved_2@MFepAttributeStorer@@EAEXXZ @ 63 NONAME ; private: virtual void __thiscall MFepAttributeStorer::MFepAttributeStorer_Reserved_2(void)
	?MFepAttributeStorer_Reserved_1@CCoeFep@@EAEXXZ @ 64 NONAME ; private: virtual void __thiscall CCoeFep::MFepAttributeStorer_Reserved_1(void)
	?MFepAttributeStorer_Reserved_2@CCoeFep@@EAEXXZ @ 65 NONAME ; private: virtual void __thiscall CCoeFep::MFepAttributeStorer_Reserved_2(void)
	?MCoeFocusObserver_Reserved_1@CCoeFep@@EAEXXZ @ 66 NONAME ; private: virtual void __thiscall CCoeFep::MCoeFocusObserver_Reserved_1(void)
	?MCoeFocusObserver_Reserved_2@CCoeFep@@EAEXXZ @ 67 NONAME ; private: virtual void __thiscall CCoeFep::MCoeFocusObserver_Reserved_2(void)
	?MCoeForegroundObserver_Reserved_1@CCoeFep@@EAEXXZ @ 68 NONAME ; private: virtual void __thiscall CCoeFep::MCoeForegroundObserver_Reserved_1(void)
	?MCoeForegroundObserver_Reserved_2@CCoeFep@@EAEXXZ @ 69 NONAME ; private: virtual void __thiscall CCoeFep::MCoeForegroundObserver_Reserved_2(void)
	?MCoeMessageObserver_Reserved_1@CCoeFep@@EAEXXZ @ 70 NONAME ; private: virtual void __thiscall CCoeFep::MCoeMessageObserver_Reserved_1(void)
	?MCoeMessageObserver_Reserved_2@CCoeFep@@EAEXXZ @ 71 NONAME ; private: virtual void __thiscall CCoeFep::MCoeMessageObserver_Reserved_2(void)
	?WriteAttributeDataAndBroadcastL@CCoeFep@@IAEXABV?$TArray@VTUid@@@@@Z @ 72 NONAME ; protected: void __thiscall CCoeFep::WriteAttributeDataAndBroadcastL(class TArray<class TUid> const &)
	?HandleCompletionOfTransactionL@MCoeFepObserver@@UAEXXZ @ 73 NONAME ; public: virtual void __thiscall MCoeFepObserver::HandleCompletionOfTransactionL(void)
	?HandleStartOfTransactionL@MCoeFepObserver@@UAEXXZ @ 74 NONAME ; public: virtual void __thiscall MCoeFepObserver::HandleStartOfTransactionL(void)
	?MFepPointerEventHandlerDuringInlineEdit_Reserved_1@MFepPointerEventHandlerDuringInlineEdit@@EAEXXZ @ 75 NONAME ; private: virtual void __thiscall MFepPointerEventHandlerDuringInlineEdit::MFepPointerEventHandlerDuringInlineEdit_Reserved_1(void)
	?MFepPointerEventHandlerDuringInlineEdit_Reserved_2@MFepPointerEventHandlerDuringInlineEdit@@EAEXXZ @ 76 NONAME ; private: virtual void __thiscall MFepPointerEventHandlerDuringInlineEdit::MFepPointerEventHandlerDuringInlineEdit_Reserved_2(void)
	?CommitFepInlineEditL@MCoeFepAwareTextEditor@@QAEXAAVCCoeEnv@@@Z @ 77 NONAME ; public: void __thiscall MCoeFepAwareTextEditor::CommitFepInlineEditL(class CCoeEnv &)
	?MFileObserver_Reserved_1@MFileObserver@CFepFastFileAccessor@@EAEXXZ @ 78 NONAME ABSENT ; private: virtual void __thiscall CFepFastFileAccessor::MFileObserver::MFileObserver_Reserved_1(void)
	?MFileObserver_Reserved_2@MFileObserver@CFepFastFileAccessor@@EAEXXZ @ 79 NONAME ABSENT ; private: virtual void __thiscall CFepFastFileAccessor::MFileObserver::MFileObserver_Reserved_2(void)
	?MModifiedCharacter_Reserved_1@MModifiedCharacter@CCoeFep@@EAEXXZ @ 80 NONAME ; private: virtual void __thiscall CCoeFep::MModifiedCharacter::MModifiedCharacter_Reserved_1(void)
	?MModifiedCharacter_Reserved_2@MModifiedCharacter@CCoeFep@@EAEXXZ @ 81 NONAME ; private: virtual void __thiscall CCoeFep::MModifiedCharacter::MModifiedCharacter_Reserved_2(void)
	?SimulateKeyEventsL@CCoeFep@@IAEXABV?$TArray@VMModifiedCharacter@CCoeFep@@@@@Z @ 82 NONAME ; protected: void __thiscall CCoeFep::SimulateKeyEventsL(class TArray<class CCoeFep::MModifiedCharacter> const &)
	??0CState@MCoeFepAwareTextEditor_Extension1@@IAE@XZ @ 83 NONAME ; protected: __thiscall MCoeFepAwareTextEditor_Extension1::CState::CState(void)
	??1CState@MCoeFepAwareTextEditor_Extension1@@UAE@XZ @ 84 NONAME ; public: virtual __thiscall MCoeFepAwareTextEditor_Extension1::CState::~CState(void)
	?BaseConstructL@CState@MCoeFepAwareTextEditor_Extension1@@IAEXXZ @ 85 NONAME ; protected: void __thiscall MCoeFepAwareTextEditor_Extension1::CState::BaseConstructL(void)
	?CState_Reserved_1@CState@MCoeFepAwareTextEditor_Extension1@@EAEXXZ @ 86 NONAME ; private: virtual void __thiscall MCoeFepAwareTextEditor_Extension1::CState::CState_Reserved_1(void)
	?CState_Reserved_2@CState@MCoeFepAwareTextEditor_Extension1@@EAEXXZ @ 87 NONAME ; private: virtual void __thiscall MCoeFepAwareTextEditor_Extension1::CState::CState_Reserved_2(void)
	?CState_Reserved_3@CState@MCoeFepAwareTextEditor_Extension1@@EAEXXZ @ 88 NONAME ; private: virtual void __thiscall MCoeFepAwareTextEditor_Extension1::CState::CState_Reserved_3(void)
	?CState_Reserved_4@CState@MCoeFepAwareTextEditor_Extension1@@EAEXXZ @ 89 NONAME ; private: virtual void __thiscall MCoeFepAwareTextEditor_Extension1::CState::CState_Reserved_4(void)
	?Extension1@MCoeFepAwareTextEditor@@QAEPAVMCoeFepAwareTextEditor_Extension1@@XZ @ 90 NONAME ; public: class MCoeFepAwareTextEditor_Extension1 * __thiscall MCoeFepAwareTextEditor::Extension1(void)
	?StartFepInlineEditL@MCoeFepAwareTextEditor_Extension1@@UAEXAAHABVTCursorSelection@@ABVTDesC16@@HHPBVMFormCustomDraw@@AAVMFepInlineTextFormatRetriever@@AAVMFepPointerEventHandlerDuringInlineEdit@@@Z @ 91 NONAME ; public: virtual void __thiscall MCoeFepAwareTextEditor_Extension1::StartFepInlineEditL(int &,class TCursorSelection const &,class TDesC16 const &,int,int,class MFormCustomDraw const *,class MFepInlineTextFormatRetriever &,class MFepPointerEventHandlerDuringInlineEdit &)
	?SetCursorType@MCoeFepAwareTextEditor_Extension1@@UAEXAAHABUTTextCursor@@@Z @ 92 NONAME ; public: virtual void __thiscall MCoeFepAwareTextEditor_Extension1::SetCursorType(int &,struct TTextCursor const &)
	?GetFepLayDocExtension@MCoeFepAwareTextEditor_Extension1@@UAEPAVMCoeFepLayDocExtension@@AAH@Z @ 93 NONAME ; public: virtual class MCoeFepLayDocExtension * __thiscall MCoeFepAwareTextEditor_Extension1::GetFepLayDocExtension(int &)
	?MCoeFepAwareTextEditor_Extension1_Reserved_4@MCoeFepAwareTextEditor_Extension1@@EAEXXZ @ 94 NONAME ; private: virtual void __thiscall MCoeFepAwareTextEditor_Extension1::MCoeFepAwareTextEditor_Extension1_Reserved_4(void)
	?OnFinishingHandlingKeyEvent_WithDownUpFilterL@CCoeFep@@QAE?AW4TKeyResponse@@W4TEventCode@@ABUTKeyEvent@@W42@@Z @ 95 NONAME ; public: enum TKeyResponse  __thiscall CCoeFep::OnFinishingHandlingKeyEvent_WithDownUpFilterL(enum TEventCode,struct TKeyEvent const &,enum TKeyResponse)
	?OnStartingHandlingKeyEvent_WithDownUpFilterLC@CCoeFep@@QAEXXZ @ 96 NONAME ; public: void __thiscall CCoeFep::OnStartingHandlingKeyEvent_WithDownUpFilterLC(void)
	?OnFinishingHandlingKeyEvent_NoDownUpFilterL@CCoeFep@@QAE?AW4TKeyResponse@@W4TEventCode@@ABUTKeyEvent@@W42@@Z @ 97 NONAME ; public: enum TKeyResponse  __thiscall CCoeFep::OnFinishingHandlingKeyEvent_NoDownUpFilterL(enum TEventCode,struct TKeyEvent const &,enum TKeyResponse)
	?OnStartingHandlingKeyEvent_NoDownUpFilterLC@CCoeFep@@QAEXXZ @ 98 NONAME ; public: void __thiscall CCoeFep::OnStartingHandlingKeyEvent_NoDownUpFilterLC(void)
	?MCoeFepLayDocExtension_Reserved_1@MCoeFepLayDocExtension@@EAEXXZ @ 99 NONAME ; private: virtual void __thiscall MCoeFepLayDocExtension::MCoeFepLayDocExtension_Reserved_1(void)
	?MCoeFepLayDocExtension_Reserved_2@MCoeFepLayDocExtension@@EAEXXZ @ 100 NONAME ; private: virtual void __thiscall MCoeFepLayDocExtension::MCoeFepLayDocExtension_Reserved_2(void)
	??8TFepOnOrOffKeyData@@QBEHABV0@@Z @ 101 NONAME ; int TFepOnOrOffKeyData::operator==(class TFepOnOrOffKeyData const &) const
	??9TFepOnOrOffKeyData@@QBEHABV0@@Z @ 102 NONAME ; int TFepOnOrOffKeyData::operator!=(class TFepOnOrOffKeyData const &) const
	?NewL@CFepGenericGlobalSettings@@SAPAV1@XZ @ 103 NONAME ; class CFepGenericGlobalSettings * CFepGenericGlobalSettings::NewL(void)
	?NewLC@CFepGenericGlobalSettings@@SAPAV1@XZ @ 104 NONAME ; class CFepGenericGlobalSettings * CFepGenericGlobalSettings::NewLC(void)
	?ReadOnOrOffKeyData@CFepGenericGlobalSettings@@SAXAAVCRepository@@AAVTFepOnOrOffKeyData@@KPAH@Z @ 105 NONAME ; void CFepGenericGlobalSettings::ReadOnOrOffKeyData(class CRepository &, class TFepOnOrOffKeyData &, unsigned long, int *)
	?ReadOnState@CFepGenericGlobalSettings@@SAXAAVCRepository@@AAHPAH@Z @ 106 NONAME ; void CFepGenericGlobalSettings::ReadOnState(class CRepository &, int &, int *)
	?WriteOnOrOffKeyDataAndBroadcastL@CFepGenericGlobalSettings@@SAXAAVCRepository@@ABVTFepOnOrOffKeyData@@K@Z @ 107 NONAME ; void CFepGenericGlobalSettings::WriteOnOrOffKeyDataAndBroadcastL(class CRepository &, class TFepOnOrOffKeyData const &, unsigned long)
	?WriteOnStateAndBroadcastL@CFepGenericGlobalSettings@@SAXAAVCRepository@@HK@Z @ 108 NONAME ; void CFepGenericGlobalSettings::WriteOnStateAndBroadcastL(class CRepository &, int, unsigned long)

